@@ -28,18 +28,14 @@ plotres<-function(a){
   resid<-a$residuos
   df.resid<-a$gl.residual
   fitted.val<-a$valores.ajustados
-  var.res<- sum(resid^2)/df.resid
-  respad<- resid/sqrt(var.res)
+  var.res<-sum(resid^2)/df.resid
+  respad<-resid/sqrt(var.res)
   par(mfrow=c(2,2))
-  # Grafico1
+  #Grafico1
   hist(respad, xlab="Residuos padronizados", ylab="Densidade", main="Histograma", freq=FALSE)
   x<-c()
   curve(dnorm(x,mean=0,sd=1),col=2,lty=1,lwd=1,add=TRUE)
-  #plot(fitted.val, resid, xlab="Fitted Values", ylab="Residuals")
-  #abline(h=0, col = "lightgray", lty = 3)
-  #title("Residuals vs Fitted Values")
-  #
-  # Grafico2 P-Pplot com as bandas de confian?a https://stats.stackexchange.com/questions/111288/confidence-bands-for-qq-line
+  #Grafico2
   good<-!is.na(resid)
   ord<-order(resid[good])
   ord.x<-resid[good][ord]
@@ -60,13 +56,12 @@ plotres<-function(a){
   lines(z,upper,lty=2,lwd=2,col="red")
   lines(z,lower,lty=2,lwd=2,col="red")
   title("Normal Q-Q (95%)")
-  #
-  # Grafico3 Res?duos standardizados versus Valores Ajustados da Vari?vel Resposta
-  plot(fitted.val, respad, xlab="Valores ajustados", ylab="Residuos padronizados")
-  abline(h=0,  col = "red", lty = 3)
+  # Grafico3
+  plot(fitted.val,respad,xlab="Valores ajustados",ylab="Residuos padronizados")
+  abline(h=0,col="red",lty=3)
   title("Residuos padronizados vs Valores ajustados")
-  #
   # Grafico4
   boxplot(respad)
   title("Residuos padronizados")
+  par(mfrow=c(1,1))
 }
